==> v23.05.zip: bookstack/lang/ja/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'キャンセル',
    'confirm' => '確認',
    'back' => '戻る',
    'save' => '保存',
    'continue' => '続ける',
    'select' => '選択',
    'toggle_all' => '一括切替',
    'more' => 'その他',

    // Form Labels
    'name' => '名称',
    'description' => '概要',
    'role' => '権限',
    'cover_image' => 'カバー画像',
    'cover_image_description' => 'この画像はおよそ440x250pxの大きさが必要です。',

    // Actions
    'actions' => '実行',
    'view' => '表示',
    'view_all' => 'すべて表示',
    'new' => '新規作成',
    'create' => '作成',
    'update' => '更新',
    'edit' => '編集',
    'sort' => '並び順',
    'move' => '移動',
    'copy' => 'コピー',
    'reply' => '返信',
    'delete' => '削除',
    'delete_confirm' => '確認して削除',
    'search' => '検索',
    'search_clear' => '検索をクリア',
    'reset' => 'リセット',
    'remove' => '削除',
    'add' => '追加',
    'configure' => '設定',
    'fullscreen' => '全画面',
    'favourite' => 'お気に入り',
    'unfavourite' => 'お気に入りから削除',
    'next' => '次へ',
    'previous' => '前へ',
    'filter_active' => '有効なフィルター:',
    'filter_clear' => 'フィルターを解除',
    'download' => 'ダウンロード',
    'open_in_tab' => 'タブで開く',

    // Sort Options
    'sort_options' => '並べ替えオプション',
    'sort_direction_toggle' => '並べ替え方向の切り替え',
    'sort_ascending' => '昇順に並べ替え',
    'sort_descending' => '降順に並べ替え',
    'sort_name' => '名前',
    'sort_default' => 'デフォルト',
    'sort_created_at' => '作成日',
    'sort_updated_at' => '更新日',

    // Misc
    'deleted_user' => '削除済みユーザ',
    'no_activity' => '表示するアクティビティがありません',
    'no_items' => 'アイテムはありません',
    'back_to_top' => '上に戻る',
    'skip_to_main_content' => 'メインコンテンツへスキップ',
    'toggle_details' => '概要の表示切替',
    'toggle_thumbnails' => 'Toggle Thumbnails',
    'details' => '詳細',
    'grid_view' => 'グリッド形式',
    'list_view' => 'リスト形式',
    'default' => 'デフォルト',
    'breadcrumb' => 'パンくずリスト',
    'status' => '状態',
    'status_active' => '有効',
    'status_inactive' => '無効',
    'never' => '該当なし',
    'none' => 'なし',

    // Header
    'homepage' => 'ホームページ',
    'header_menu_expand' => 'ヘッダーメニューを展開',
    'profile_menu' => 'プロフィールメニュー',
    'view_profile' => 'プロフィール表示',
    'edit_profile' => 'プロフィール編集',
    'dark_mode' => 'ダークモード',
    'light_mode' => 'ライトモード',
    'global_search' => 'グローバル検索',

    // Layout tabs
    'tab_info' => '情報',
    'tab_info_label' => 'タブ: サブコンテンツを表示',
    'tab_content' => '内容',
    'tab_content_label' => 'タブ: メインコンテンツを表示',

    // Email Content
    'email_action_help' => '":actionText" をクリックできない場合、以下のURLをコピーしブラウザで開いてください:',
    'email_rights' => 'All rights reserved',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'プライバシーポリシー',
    'terms_of_service' => '利用規約',
];

==> v23.10.zip: bookstack/lang/ja/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'キャンセル',
    'close' => '閉じる',
    'confirm' => '確認',
    'back' => '戻る',
    'save' => '保存',
    'continue' => '続ける',
    'select' => '選択',
    'toggle_all' => '一括切替',
    'more' => 'その他',

    // Form Labels
    'name' => '名称',
    'description' => '概要',
    'role' => '権限',
    'cover_image' => 'カバー画像',
    'cover_image_description' => 'この画像はおよそ440x250pxの大きさが必要です。',

    // Actions
    'actions' => '実行',
    'view' => '表示',
    'view_all' => 'すべて表示',
    'new' => '新規作成',
    'create' => '作成',
    'update' => '更新',
    'edit' => '編集',
    'sort' => '並び順',
    'move' => '移動',
    'copy' => 'コピー',
    'reply' => '返信',
    'delete' => '削除',
    'delete_confirm' => '確認して削除',
    'search' => '検索',
    'search_clear' => '検索をクリア',
    'reset' => 'リセット',
    'remove' => '削除',
    'add' => '追加',
    'configure' => '設定',
    'manage' => '管理',
    'fullscreen' => '全画面',
    'favourite' => 'お気に入り',
    'unfavourite' => 'お気に入りから削除',
    'next' => '次へ',
    'previous' => '前へ',
    'filter_active' => '有効なフィルター:',
    'filter_clear' => 'フィルターを解除',
    'download' => 'ダウンロード',
    'open_in_tab' => 'タブで開く',
    'open' => 'Open',

    // Sort Options
    'sort_options' => '並べ替えオプション',
    'sort_direction_toggle' => '並べ替え方向の切り替え',
    'sort_ascending' => '昇順に並べ替え',
    'sort_descending' => '降順に並べ替え',
    'sort_name' => '名前',
    'sort_default' => 'デフォルト',
    'sort_created_at' => '作成日',
    'sort_updated_at' => '更新日',

    // Misc
    'deleted_user' => '削除済みユーザ',
    'no_activity' => '表示するアクティビティがありません',
    'no_items' => 'アイテムはありません',
    'back_to_top' => '上に戻る',
    'skip_to_main_content' => 'メインコンテンツへスキップ',
    'toggle_details' => '概要の表示切替',
    'toggle_thumbnails' => 'サムネイルの切り替え',
    'details' => '詳細',
    'grid_view' => 'グリッド形式',
    'list_view' => 'リスト形式',
    'default' => 'デフォルト',
    'breadcrumb' => 'パンくずリスト',
    'status' => '状態',
    'status_active' => '有効',
    'status_inactive' => '無効',
    'never' => '該当なし',
    'none' => 'なし',

    // Header
    'homepage' => 'ホームページ',
    'header_menu_expand' => 'ヘッダーメニューを展開',
    'profile_menu' => 'プロフィールメニュー',
    'view_profile' => 'プロフィール表示',
    'edit_profile' => 'プロフィール編集',
    'dark_mode' => 'ダークモード',
    'light_mode' => 'ライトモード',
    'global_search' => 'グローバル検索',

    // Layout tabs
    'tab_info' => '情報',
    'tab_info_label' => 'タブ: サブコンテンツを表示',
    'tab_content' => '内容',
    'tab_content_label' => 'タブ: メインコンテンツを表示',

    // Email Content
    'email_action_help' => '":actionText" をクリックできない場合、以下のURLをコピーしブラウザで開いてください:',
    'email_rights' => 'All rights reserved',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'プライバシーポリシー',
    'terms_of_service' => '利用規約',
];
